==> discord-embeds-pages-buttons-1.0.2.tgz: package/index.js <==

exports.pages = async function(client, message, pages, timeout, disbut, style){
    const Discord = require("discord.js");
    require("discord-buttons");
    var timeForStart = Date.now();
    if(pages.find(k=> k.length >= 5)){
        console.error("Amount of rows in a page must be 4 or below!");
        return;
    }
    const pageMovingButtons1 = new disbut.MessageButton()
    .setID(`forward_button_embed`)
    .setLabel("")
    .setEmoji("⏩")
    .setStyle(style)
    const pageMovingButtons2 = new disbut.MessageButton()
    .setID(`back_button_embed`)
    .setLabel("")
    .setEmoji("⏪")
    .setStyle(style)
    var pageMovingButtons = new disbut.MessageActionRow()
    .addComponent(pageMovingButtons2)
    .addComponent(pageMovingButtons1)
    var currentPage = 0;
    var m = await message.channel.send(pages[0], {components: [pageMovingButtons]});
    client.on("clickButton", async b=>{
        console.log("wee")
        if(Date.now() - timeForStart >= timeout)return;
        if(b.message.id == m.id && b.message.author.id == message.author.id){
        if(b.id == "back_button_embed"){
            if(currentPage - 1 < 0){
                currentPage = pages.length - 1
            } else{
                currentPage -= 1;
            }
        } else if(b.id == "forward_button_embed"){
            if(currentPage + 1 == pages.length){
                currentPage = 0;
            } else{
                currentPage += 1;
            }
            console.log("woo")
        }
        if(b.id == "back_button_embed" || b.id == "forward_button_embed"){
            m.edit(pages[currentPage]);
            b.defer(true);
        }
    }
    })
}

==> discord-embeds-pages-buttons-1.0.3.tgz: package/index.js <==

exports.pages = async function(client, message, pages, timeout, disbut, style){
    const Discord = require("discord.js");
    require("discord-buttons");
    var timeForStart = Date.now();
    if(pages.find(k=> k.length >= 5)){
        console.error("Amount of rows in a page must be 4 or below!");
        return;
    }
    const pageMovingButtons1 = new disbut.MessageButton()
    .setID(`forward_button_embed`)
    .setLabel("")
    .setEmoji("⏩")
    .setStyle(style)
    const pageMovingButtons2 = new disbut.MessageButton()
    .setID(`back_button_embed`)
    .setLabel("")
    .setEmoji("⏪")
    .setStyle(style)
    var pageMovingButtons = new disbut.MessageActionRow()
    .addComponent(pageMovingButtons2)
    .addComponent(pageMovingButtons1)
    var currentPage = 0;
    var m = await message.channel.send("wee"/*pages[0]*/, {components: [pageMovingButtons]});
    client.on("clickButton", async b=>{
        console.log("wee")
        if(Date.now() - timeForStart >= timeout)return;
        if(b.message.id == m.id && b.message.author.id == message.author.id){
        if(b.id == "back_button_embed"){
            if(currentPage - 1 < 0){
                currentPage = pages.length - 1
            } else{
                currentPage -= 1;
            }
        } else if(b.id == "forward_button_embed"){
            if(currentPage + 1 == pages.length){
                currentPage = 0;
            } else{
                currentPage += 1;
            }
            console.log("woo")
        }
        if(b.id == "back_button_embed" || b.id == "forward_button_embed"){
            m.edit(pages[currentPage]);
            b.defer(true);
        }
    }
    })
}
